<?php

if (!function_exists('synth_rift_slide_metaboxes')) {

    function synth_rift_slide_init_meta_boxes() {
        if (!class_exists('Custom_Meta_Box')) {
            require_once( 'lib/metaboxes/custom-meta-box-class.php' );
        }
    }

    add_action('init', 'synth_rift_slide_init_meta_boxes', 9999);
}

if (!function_exists('synth_rift_slide_metaboxes')) {

function synth_rift_slide_metaboxes($meta_boxes) {

    $prefix = SYNTH_RIFT_SLIDER_META; // Prefix for all fields
    $prefix_global = SYNTH_RIFT_SLIDER_OPT;

    $max_angle = get_option($prefix_global . 'max_angle');
    $max_scale = get_option($prefix_global . 'max_scale');

    $meta_boxes[] = array(
        'id' => 'slider_text_styling_metabox',
        'title' => 'Slide Text Styling',
        'pages' => array('rift_slide'), // post type
        'context' => 'normal',
        'priority' => 'low',
        'show_names' => true, // Show field names on the left
        'promotion' => array(
            'title' => 'Want more styling options?',
            'content' => _('You are currently using the lite version of the Rift Slider.  Upgrade today to unlock extra styling features such as: Coloring text, background colors and transparency settings.') . ' <a href="http://www.syntaxthemes.co.uk/shop/rift-slider-full-version/" target="_blank">Upgrade the Rift Slider.</a>'
        ),
        'fields' => array(
            array(
                'name' => 'Title Text Size',
                'desc' => __('Choose the font size for the title.'),
                'id' => $prefix . 'title_font_size',
                'type' => 'select',
                'std' => '100%',
                'options' => array(
                    array('name' => '130%', 'value' => '130%'),
                    array('name' => '120%', 'value' => '120%'),
                    array('name' => '110%', 'value' => '110%'),
                    array('name' => '100%', 'value' => '100%'),
                    array('name' => '80%', 'value' => '80%'),
                    array('name' => '60%', 'value' => '60%'),
                    array('name' => '40%', 'value' => '40%'),
                    array('name' => '20%', 'value' => '20%'),
                )
            ),
            array(
                'name' => 'Excerpt Text Size',
                'desc' => __('Choose the font size for the excerpt.'),
                'id' => $prefix . 'excerpt_font_size',
                'type' => 'select',
                'std' => '100%',
                'options' => array(
                    array('name' => '130%', 'value' => '130%'),
                    array('name' => '120%', 'value' => '120%'),
                    array('name' => '110%', 'value' => '110%'),
                    array('name' => '100%', 'value' => '100%'),
                    array('name' => '80%', 'value' => '80%'),
                    array('name' => '60%', 'value' => '60%'),
                    array('name' => '40%', 'value' => '40%'),
                    array('name' => '20%', 'value' => '20%'),
                )
            )
        )
    );

    $meta_boxes[] = array(
        'id' => 'slider_text_positioning_metabox',
        'title' => 'Slide Text Positioning',
        'pages' => array('rift_slide'), // post type
        'context' => 'normal',
        'priority' => 'low',
        'show_names' => true, // Show field names on the left
        'promotion' => array(
            'title' => 'Want more styling options?',
            'content' => _('You are currently using the lite version of the Rift Slider.  Upgrade today to unlock extra styling features and use this simple text positioning control to position your title and excerpt.') . ' <a href="http://www.syntaxthemes.co.uk/shop/rift-slider-full-version/" target="_blank">Upgrade the Rift Slider.</a>'
        ),
        'fields' => array(
            array(
                'name' => 'Slider Layouts',
                'desc' => __('Choose a layout position for the slider text.'),
                'id' => $prefix . 'text_positioning',
                'type' => 'image-radio',
                'std' => 'top-left',
                'display' => 'inline',
                'options' => array(
                    array('name' => $prefix . 'text_positioning', 'value' => 'top-left', 'url' => plugins_url('images/text-positioning.png', dirname(__FILE__))),
                )
            )
        )
    );

    $meta_boxes[] = array(
        'id' => 'slide_transformation_metabox',
        'title' => 'Slide Transformations',
        'pages' => array('rift_slide'), // post type
        'context' => 'normal',
        'priority' => 'low',
        'show_names' => true, // Show field names on the left
        'fields' => array(
            array(
                'name' => 'Slice Orientation',
                'desc' => __('Choose the direction of slicing the slide.'),
                'id' => $prefix . 'orientation',
                'type' => 'select',
                'options' => array(
                    array('name' => 'Vertical', 'value' => 'vertical'),
                    array('name' => 'Horizontal', 'value' => 'horizontal')
                ),
            ),
            array(
                'name' => 'Slice 1 Rotation',
                'desc' => __('Set the first slice rotation degree.'),
                'id' => $prefix . 'rotation_1',
                'std' => '-25',
                'type' => 'text',
                'validations' => array(
                    array(
                        'type' => 'required'
                    ),
                    array(
                        'type' => 'number',
                        'min' => '0',
                        'max' => $max_angle
                    )
                )
            ),
            array(
                'name' => 'Slice 2 Rotation',
                'desc' => __('Set the second slice rotation degree.'),
                'id' => $prefix . 'rotation_2',
                'std' => '25',
                'type' => 'text',
                'validations' => array(
                    array(
                        'type' => 'required'
                    ),
                    array(
                        'type' => 'number',
                        'min' => '0',
                        'max' => $max_angle
                    )
                )
            ),
            array(
                'name' => 'Slice 1 Scale',
                'desc' => __('Set the first slice scale factor.'),
                'id' => $prefix . 'scale_1',
                'std' => '2',
                'type' => 'text',
                'validations' => array(
                    array(
                        'type' => 'required'
                    ),
                    array(
                        'type' => 'number',
                        'min' => '0',
                        'max' => $max_scale
                    )
                )
            ),
            array(
                'name' => 'Slice 2 Scale',
                'desc' => __('Set the second slice scale factor.'),
                'id' => $prefix . 'scale_2',
                'std' => '2',
                'type' => 'text',
                'validations' => array(
                    array(
                        'type' => 'required'
                    ),
                    array(
                        'type' => 'number',
                        'min' => '0',
                        'max' => $max_scale
                    )
                )
            )
        )
    );

    return $meta_boxes;
}

    add_filter('synth_meta_boxes', 'synth_rift_slide_metaboxes');
}
?>